@@ -7,6 +7,10 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <iostream>
 #include <sstream>
 #include <stdio.h>
@@ -16,18 +20,33 @@
 #include <librevenge/librevenge.h>
 #include <libvisio/libvisio.h>
 
+#ifndef VERSION
+#define VERSION "UNKNOWN VERSION"
+#endif
+
 namespace
 {
 
 int printUsage()
 {
-  printf("Usage: vss2xhtml [OPTION] <Visio Stencils File>\n");
+  printf("`vss2xhtml' converts Microsoft Visio stencils to SVG.\n");
+  printf("\n");
+  printf("Usage: vss2xhtml [OPTION] INPUT\n");
   printf("\n");
   printf("Options:\n");
-  printf("--help                Shows this help message\n");
+  printf("\t--help                show this help message\n");
+  printf("\t--version             show version information\n");
+  printf("\n");
+  printf("Report bugs to <https://bugs.documentfoundation.org/>.\n");
   return -1;
 }
 
+int printVersion()
+{
+  printf("vss2xhtml " VERSION "\n");
+  return 0;
+}
+
 } // anonymous namespace
 
 int main(int argc, char *argv[])
@@ -35,11 +54,13 @@ int main(int argc, char *argv[])
   if (argc < 2)
     return printUsage();
 
-  char *file = 0;
+  char *file = nullptr;
 
   for (int i = 1; i < argc; i++)
   {
-    if (!file && strncmp(argv[i], "--", 2))
+    if (!strcmp(argv[i], "--version"))
+      return printVersion();
+    else if (!file && strncmp(argv[i], "--", 2))
       file = argv[i];
     else
       return printUsage();
